==> qtjambi-qt3danimation-jre8-5.15.4-sources.jar: io/qt/qt3d/animation/QAnimationAspect.java <==
package io.qt.qt3d.animation;


/**
 * <p>Provides key-frame animation capabilities to Qt 3D</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qanimationaspect.html">Qt3DAnimation::QAnimationAspect</a></p>
 */
public class QAnimationAspect extends io.qt.qt3d.core.QAbstractAspect
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAnimationAspect.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QAnimationAspect(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QAnimationAspect() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qanimationaspect.html#QAnimationAspect">Qt3DAnimation::QAnimationAspect::QAnimationAspect(QObject*)</a></p>
     */
    public QAnimationAspect(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAnimationAspect instance, io.qt.core.QObject parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAnimationAspect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAnimationAspect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAnimationAspect instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3danimation-jre8-6.2.1-sources.jar: io/qt/qt3d/animation/QAnimationAspect.java <==
package io.qt.qt3d.animation;


/**
 * <p>Provides key-frame animation capabilities to Qt 3D</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qanimationaspect.html">Qt3DAnimation::QAnimationAspect</a></p>
 */
public class QAnimationAspect extends io.qt.qt3d.core.QAbstractAspect
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAnimationAspect.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QAnimationAspect(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QAnimationAspect() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qanimationaspect.html#QAnimationAspect">Qt3DAnimation::QAnimationAspect::QAnimationAspect(QObject*)</a></p>
     */
    public QAnimationAspect(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAnimationAspect instance, io.qt.core.QObject parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAnimationAspect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAnimationAspect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAnimationAspect instance, QDeclarativeConstructor constructor);
    
}
